@@ -21,15 +21,14 @@ import logging
 import os
 import re
 import socket
+from urllib import parse
 
 import netaddr
+from netaddr.core import INET_PTON
 import netifaces
-import six
-from six.moves.urllib import parse
 
 from oslo_utils._i18n import _
-from oslo_utils._i18n import _LI
-from oslo_utils._i18n import _LW
+
 
 LOG = logging.getLogger(__name__)
 _IS_IPV6_ENABLED = None
@@ -83,17 +82,43 @@ def parse_host_port(address, default_port=None):
     return (host, None if port is None else int(port))
 
 
-def is_valid_ipv4(address):
+def is_valid_ipv4(address, strict=None):
     """Verify that address represents a valid IPv4 address.
 
     :param address: Value to verify
     :type address: string
+    :param strict: flag allowing users to restrict validation
+        to IP addresses in presentation format (``a.b.c.d``) as opposed to
+        address format (``a.b.c.d``, ``a.b.c``, ``a.b``, ``a``).
+    :type flags: bool
     :returns: bool
 
     .. versionadded:: 1.1
+    .. versionchanged:: 4.8.0
+       Allow to restrict validation to IP addresses in presentation format
+       (``a.b.c.d``) as opposed to address format
+       (``a.b.c.d``, ``a.b.c``, ``a.b``, ``a``).
     """
+    if strict is not None:
+        flag = INET_PTON if strict else 0
+        try:
+            return netaddr.valid_ipv4(address, flags=flag)
+        except netaddr.AddrFormatError:
+            return False
+
+    # non strict mode
     try:
-        return netaddr.valid_ipv4(address)
+        if netaddr.valid_ipv4(address, flags=INET_PTON):
+            return True
+        else:
+            if netaddr.valid_ipv4(address):
+                LOG.warn(
+                    'Converting in non strict mode is deprecated. '
+                    'You should pass strict=False if you want to '
+                    'preserve legacy behavior')
+                return True
+            else:
+                return False
     except netaddr.AddrFormatError:
         return False
 
@@ -194,6 +219,35 @@ def get_ipv6_addr_by_EUI64(prefix, mac):
                           'EUI-64: %s') % prefix)
 
 
+def get_mac_addr_by_ipv6(ipv6, dialect=netaddr.mac_unix_expanded):
+    """Extract MAC address from interface identifier based IPv6 address.
+
+    For example from link-local addresses (fe80::/10) generated from MAC.
+
+    :param ipv6: An interface identifier (i.e. mostly MAC) based IPv6
+                 address as a netaddr.IPAddress() object.
+    :param dialect: The netaddr dialect of the the object returned.
+                    Defaults to netaddr.mac_unix_expanded.
+    :returns: A MAC address as a netaddr.EUI() object.
+
+    See also:
+    * https://tools.ietf.org/html/rfc4291#appendix-A
+    * https://tools.ietf.org/html/rfc4291#section-2.5.6
+
+    .. versionadded:: 4.3.0
+    """
+    return netaddr.EUI(int(
+        # out of the lowest 8 bytes (byte positions 8-1)
+        # delete the middle 2 bytes (5-4, 0xff_fe)
+        # by shifting the highest 3 bytes to the right by 2 bytes (8-6 -> 6-4)
+        (((ipv6 & 0xff_ff_ff_00_00_00_00_00) >> 16) +
+         # adding the lowest 3 bytes as they are (3-1)
+         (ipv6 & 0xff_ff_ff)) ^
+        # then invert the universal/local bit
+        0x02_00_00_00_00_00),
+        dialect=dialect)
+
+
 def is_ipv6_enabled():
     """Check if IPv6 support is enabled on the platform.
 
@@ -218,6 +272,20 @@ def is_ipv6_enabled():
     return _IS_IPV6_ENABLED
 
 
+def escape_ipv6(address):
+    """Escape an IP address in square brackets if IPv6
+
+    :param address: address to optionaly escape
+    :type address: string
+    :returns: string
+
+    .. versionadded:: 3.29.0
+    """
+    if is_valid_ipv6(address):
+        return "[%s]" % address
+    return address
+
+
 def is_valid_ip(address):
     """Verify that address represents a valid IP address.
 
@@ -242,7 +310,7 @@ def is_valid_mac(address):
     .. versionadded:: 3.17
     """
     m = "[0-9a-f]{2}(:[0-9a-f]{2}){5}$"
-    return (isinstance(address, six.string_types) and
+    return (isinstance(address, str) and
             re.match(m, address.lower()))
 
 
@@ -330,19 +398,19 @@ def _get_my_ipv4_address():
     try:
         interface = gtw['default'][netifaces.AF_INET][1]
     except (KeyError, IndexError):
-        LOG.info(_LI('Could not determine default network interface, '
-                     'using 127.0.0.1 for IPv4 address'))
+        LOG.info('Could not determine default network interface, '
+                 'using 127.0.0.1 for IPv4 address')
         return LOCALHOST
 
     try:
         return netifaces.ifaddresses(interface)[netifaces.AF_INET][0]['addr']
     except (KeyError, IndexError):
-        LOG.info(_LI('Could not determine IPv4 address for interface %s, '
-                     'using 127.0.0.1'),
+        LOG.info('Could not determine IPv4 address for interface %s, '
+                 'using 127.0.0.1',
                  interface)
     except Exception as e:
-        LOG.info(_LI('Could not determine IPv4 address for '
-                     'interface %(interface)s: %(error)s'),
+        LOG.info('Could not determine IPv4 address for '
+                 'interface %(interface)s: %(error)s',
                  {'interface': interface, 'error': e})
     return LOCALHOST
 
@@ -437,18 +505,18 @@ def set_tcp_keepalive(sock, tcp_keepalive=True,
                             socket.TCP_KEEPIDLE,
                             tcp_keepidle)
         else:
-            LOG.warning(_LW('tcp_keepidle not available on your system'))
+            LOG.warning('tcp_keepidle not available on your system')
     if tcp_keepalive_interval is not None:
         if hasattr(socket, 'TCP_KEEPINTVL'):
             sock.setsockopt(socket.IPPROTO_TCP,
                             socket.TCP_KEEPINTVL,
                             tcp_keepalive_interval)
         else:
-            LOG.warning(_LW('tcp_keepintvl not available on your system'))
+            LOG.warning('tcp_keepintvl not available on your system')
     if tcp_keepalive_count is not None:
         if hasattr(socket, 'TCP_KEEPCNT'):
             sock.setsockopt(socket.IPPROTO_TCP,
                             socket.TCP_KEEPCNT,
                             tcp_keepalive_count)
         else:
-            LOG.warning(_LW('tcp_keepcnt not available on your system'))
+            LOG.warning('tcp_keepcnt not available on your system')
