@@ -21,11 +21,9 @@ Reflection module.
 """
 
 import inspect
+import logging
+import operator
 import types
-import platform
-import warnings
-
-import six
 
 try:
     _TYPE_TYPE = types.TypeType
@@ -37,16 +35,13 @@ except AttributeError:
 # others)...
 _BUILTIN_MODULES = ('builtins', '__builtin__', '__builtins__', 'exceptions')
 
-if six.PY3:
-    Parameter = inspect.Parameter
-    Signature = inspect.Signature
-    get_signature = inspect.signature
-else:
-    # Provide an equivalent but use funcsigs instead...
-    import funcsigs
-    Parameter = funcsigs.Parameter
-    Signature = funcsigs.Signature
-    get_signature = funcsigs.signature
+
+LOG = logging.getLogger(__name__)
+
+
+Parameter = inspect.Parameter
+Signature = inspect.Signature
+get_signature = inspect.signature
 
 
 def get_members(obj, exclude_hidden=True):
@@ -82,7 +77,7 @@ def get_class_name(obj, fully_qualified=True, truncate_builtins=True):
 
     if inspect.ismethod(obj):
         obj = get_method_self(obj)
-    if not isinstance(obj, six.class_types):
+    if not isinstance(obj, type):
         obj = type(obj)
     if truncate_builtins:
         try:
@@ -106,7 +101,7 @@ def get_all_class_names(obj, up_to=object,
     in order of method resolution (mro). If up_to parameter is provided,
     only name of classes that are sublcasses to that class are returned.
     """
-    if not isinstance(obj, six.class_types):
+    if not isinstance(obj, type):
         obj = type(obj)
     for cls in obj.mro():
         if issubclass(cls, up_to):
@@ -123,7 +118,7 @@ def get_callable_name(function):
     method_self = get_method_self(function)
     if method_self is not None:
         # This is a bound method.
-        if isinstance(method_self, six.class_types):
+        if isinstance(method_self, type):
             # This is a bound class method.
             im_class = method_self
         else:
@@ -160,31 +155,48 @@ def get_method_self(method):
     if not inspect.ismethod(method):
         return None
     try:
-        return six.get_method_self(method)
+        return operator.attrgetter("__self__")(method)
     except AttributeError:
         return None
 
 
 def is_same_callback(callback1, callback2, strict=True):
-    """Returns if the two callbacks are the same."""
+    """Returns if the two callbacks are the same.
+
+    'strict' arg has no meaning for python 3.8 onwards and will
+    always return the equality of both callback based on 'self'
+    comparison only.
+    """
     if callback1 is callback2:
         # This happens when plain methods are given (or static/non-bound
         # methods).
         return True
-    if not strict and platform.python_version() > '3.8':
-        warnings.warn("non strict comparison impossible in py3.8+", DeprecationWarning)
     if callback1 == callback2:
-        ## raise deprecated warning
+        # NOTE(gmann): python3.8 onward, comparison of bound methods is
+        # changed. It no longer decide the bound method's equality based
+        # on their bounded objects equality instead it checks the identity
+        # of their '__self__'. So python3.8 onward, two different bound
+        # methods are no longer equal even __eq__ method return True.
+        # Or in other term, 'strict' arg has no meaning from python 3.8
+        # onwards above if condition never satisfy if both callback are
+        # bounded to two different objects.
+        # For backward compatibility for python <3.8, we can keep the 'strict'
+        # arg and the below code of comparing 'self' and once minimum
+        # supported python version is 3.8 we can remove both because python
+        # 3.8 onward == operator itself checks identity of 'self'.
+        # Ref bug: https://bugs.launchpad.net/oslo.utils/+bug/1841072
         if not strict:
+            LOG.warning('"strict" arg is deprecated because it no '
+                        'longer work for python 3.8 onwards')
             return True
-        # Two bound methods are equal if functions themselves are equal and
-        # objects they are applied to are equal. This means that a bound
-        # method could be the same bound method on another object if the
-        # objects have __eq__ methods that return true (when in fact it is a
-        # different bound method). Python u so crazy!
+        # Until python 3.7, two bound methods are equal if functions
+        # themselves are equal and objects they are applied to are equal.
+        # This means that a bound method could be the same bound method on
+        # another object if the objects have __eq__ methods that return true
+        # (when in fact it is a different bound method). Python u so crazy!
         try:
-            self1 = six.get_method_self(callback1)
-            self2 = six.get_method_self(callback2)
+            self1 = operator.attrgetter("__self__")(callback1)
+            self2 = operator.attrgetter("__self__")(callback2)
             return self1 is self2
         except AttributeError:  # nosec
             pass
@@ -211,8 +223,8 @@ def get_callable_args(function, required_only=False):
     are not included into output.
     """
     sig = get_signature(function)
-    function_args = list(six.iterkeys(sig.parameters))
-    for param_name, p in six.iteritems(sig.parameters):
+    function_args = list(iter(sig.parameters.keys()))
+    for param_name, p in iter(sig.parameters.items()):
         if (p.kind in (Parameter.VAR_POSITIONAL, Parameter.VAR_KEYWORD) or
                 (required_only and p.default is not Parameter.empty)):
             function_args.remove(param_name)
@@ -223,4 +235,4 @@ def accepts_kwargs(function):
     """Returns ``True`` if function accepts kwargs otherwise ``False``."""
     sig = get_signature(function)
     return any(p.kind == Parameter.VAR_KEYWORD
-               for p in six.itervalues(sig.parameters))
+               for p in iter(sig.parameters.values()))
